==> groupoffice-com-4.0.47.tar.gz: groupoffice-com-4.0.47/modules/files/language/en.php <==
<?php


$l["files"]='Files';
$l["template"]= 'Template';
$l["manageTemplates"]= 'Manage templates';
$l["downloadTemplate"]= 'Download template';
$l["enterName"]= 'Enter a name';
$l["pleaseEnterName"]= 'Please enter a name';
$l["pleaseEnterNameArchive"]= 'Please enter a name for the archive';
$l["startTransfer"]= 'Start transfer';
$l["addFolder"]= 'Add folder';
$l["errorOneItem"]= 'Please select only one item';
$l["activateSharing"]= 'Activate sharing';
$l["notifyChanges"]= 'Notify me about changes in this folder';
$l["comments"]= 'Comments';
$l["downloadGOTA"]= 'Download with GOTA';
$l["fileBrowser"]= 'File browser';
$l["thumbnails"]= 'Thumbnails';
$l["saveFile"]='Save file';
$l["confirmOverwrite"]='{filename} already exists, do you want to overwrite the file?';
$l["file"]='File';
$l["emptyList"]='Empty list';
$l["newFiles"]='New';
$l["olderVersions"]='Older versions';
$l["uploadProperties"]='The properties below will be applied to all files uploaded with the "Small files" option';
$l["selectFiles"]= 'Select files';
$l["fitImage"]='Fit image';
$l["normalSize"]='Normal size';
$l["imageViewer"]='Image viewer';
$l["emailDownloadLink"]= 'Email download link';
$l["expireTime"]= 'Download link expire time';
$l["newFolder"]= 'New folder';
$l["applyState"]= 'Apply the folder\'s display settings for everyone.';
$l["stateLocked"]= 'Folder display locked by owner/admin';
$l["strDownloadActive"]= 'External download link enabled';
$l["downloadExpireTime"]='Link expires after';
$l["downloadUrl"]='URL';
$l["categoriesFiles"]= 'Custom fields for files';
$l["applyToCurrentFolder"]= 'Apply above changes to contents of only the current folder';
$l["applyRecursively"]= 'Apply above changes to contents of the current and all underlying folders';
$l["applyRecursivelyRUSure"]= 'Are you sure to apply the file customfield settings to the contents of ALL of the underlying folders? Note that this can have a great impact if you have many subfolders in this folder\'s tree structure.';
$l["pleaseConfirm"]= 'Please confirm';
$l["applyLimits"]= 'Do not show all custom field categories';
$l["undef"]= '-';
$l['name'] = 'Files';
$l['description'] = 'Files module; Module for sharing files.';

$l['fileNotFound'] = 'File not found';
$l['folderExists'] = 'The folder already exists';
$l['filenameExists'] = 'Filename %s already exists';
$l['uploadedSucces'] = 'File uploaded successfully';
$l['ootextdoc']='Open-Office Text document';
$l['wordtextdoc']='Microsoft Word document';
$l['personal']='Personal';
$l['shared']='Shared';
$l['general']='General';
$l['folder_modified_subject']='Changes to {product_name} folder';
$l['folder_modified_body']='You requested to be notified when changes are made to:
%s
The following changes were made by %s:
%s;
';
$l['modified']='Modified';
$l['new']='New';
$l['deleted']='Deleted';
$l['file']='File';
$l['folder']='Folder';
$l['files']='Files';
$l['emptyFile']='Empty file';
$l['downloadLink'] = 'Download link';
$l['deletedDownloadLink']='Delete this link';
$l['deleteDownloadLink']='You are going to delete this link, are you sure?';
$l['clickHereToDownload'] = 'Click on the link to download the file';
$l['copyPasteToDownload'] = 'Click the secured link below or copy it to your browser\'s address bar to download the file.';
$l['possibleUntil'] = 'possible until';
$l['fileNotFound']='Sorry, the file you tried to download is not found.';
$l['no_folder_id'] = 'Invalid folder id has been passed with the request to the server!';
$l['path']='Path';

$l['selectFolder']='Select folder...';
$l['notifyRecursiveTitle']='Set notification on subfolders?';
$l['removeNotifyRecursiveTitle']='Remove notification from subfolders?';
$l['notifyRecursiveQuestion']='Do you want to apply this to all the subfolders?';
$l['unlock']='Unlock';
$l['lockedBy']='Locked by';
$l['lock']='Lock';

$l['shortVersion']='Ver.';
$l['fileIsLocked']='File is locked';

$l["fileId"] = "ID";
$l["fileFolder_id"] = "Folder";
$l["fileName"] = "Name";
$l["fileLocked_user_id"] = "Locked user";
$l["fileCtime"] = "Created at";
$l["fileMtime"] = "Last modified";
$l["fileSize"] = "Size";
$l["fileUser_id"] = "User";
$l["fileComment"] = "Comment";
$l["fileExtension"] = "Extension";
$l["fileExpire_time"] = "Expire time";
$l["fileRandom_code"] = "Random Code";

$l['createDownloadLink']='Create downloadlink';

$l['notifyFolderAdd'] = 'Folder %s was add to %s by %s';
$l['notifyFolderRename'] = 'Folder %s was renamed to %s by %s';
$l['notifyFolderMove'] = 'Folder %s was moved to %s by %s';
$l['notifyFolderDelete'] = 'Folder %s was deleted by %s';

$l['notifyFileAdd'] = 'File %s was add to %s by %s';
$l['notifyFileRename'] = 'File %s was renamed to %s by %s';
$l['notifyFileMove'] = 'File %s was moved to %s by %s';
$l['notifyFileDelete'] = 'File %s was deleted by %s';
$l['notifyFileUpdate'] = 'File %s was updated by %s';
$l['notificationEmailSubject'] = 'FolderNotification Email';

==> groupoffice-com-4.0.97.tar.gz: groupoffice-com-4.0.97/modules/files/language/en.php <==
<?php


$l["files"]='Files';
$l["template"]= 'Template';
$l["manageTemplates"]= 'Manage templates';
$l["downloadTemplate"]= 'Download template';
$l["enterName"]= 'Enter a name';
$l["pleaseEnterName"]= 'Please enter a name';
$l["pleaseEnterNameArchive"]= 'Please enter a name for the archive';
$l["startTransfer"]= 'Start transfer';
$l["addFolder"]= 'Add folder';
$l["errorOneItem"]= 'Please select only one item';
$l["activateSharing"]= 'Activate sharing';
$l["notifyChanges"]= 'Notify me about changes in this folder';
$l["comments"]= 'Comments';
$l["downloadGOTA"]= 'Download with GOTA';
$l["fileBrowser"]= 'File browser';
$l["thumbnails"]= 'Thumbnails';
$l["saveFile"]='Save file';
$l["confirmOverwrite"]='{filename} already exists, do you want to overwrite the file?';
$l["file"]='File';
$l["emptyList"]='Empty list';
$l["newFiles"]='New';
$l["olderVersions"]='Older versions';
$l["uploadProperties"]='The properties below will be applied to all files uploaded with the "Small files" option';
$l["selectFiles"]= 'Select files';
$l["fitImage"]='Fit image';
$l["normalSize"]='Normal size';
$l["imageViewer"]='Image viewer';
$l["emailDownloadLink"]= 'Email download link';
$l["expireTime"]= 'Download link expire time';
$l["newFolder"]= 'New folder';
$l["applyState"]= 'Apply the folder\'s display settings for everyone.';
$l["stateLocked"]= 'Folder display locked by owner/admin';
$l["strDownloadActive"]= 'External download link enabled';
$l["downloadExpireTime"]='Link expires after';
$l["downloadUrl"]='URL';
$l["categoriesFiles"]= 'Custom fields for files';
$l["applyToCurrentFolder"]= 'Apply above changes to contents of only the current folder';
$l["applyRecursively"]= 'Apply above changes to contents of the current and all underlying folders';
$l["applyRecursivelyRUSure"]= 'Are you sure to apply the file customfield settings to the contents of ALL of the underlying folders? Note that this can have a great impact if you have many subfolders in this folder\'s tree structure.';
$l["pleaseConfirm"]= 'Please confirm';
$l["applyLimits"]= 'Do not show all custom field categories';
$l["undef"]= '-';
$l['name'] = 'Files';
$l['description'] = 'Files module; Module for sharing files.';

$l['fileNotFound'] = 'File not found';
$l['folderExists'] = 'The folder already exists';
$l['filenameExists'] = 'Filename %s already exists';
$l['uploadedSucces'] = 'File uploaded successfully';
$l['ootextdoc']='Open-Office Text document';
$l['wordtextdoc']='Microsoft Word document';
$l['personal']='Personal';
$l['shared']='Shared';
$l['general']='General';
$l['folder_modified_subject']='Changes to {product_name} folder';
$l['folder_modified_body']='You requested to be notified when changes are made to:
%s
The following changes were made by %s:
%s;
';
$l['modified']='Modified';
$l['new']='New';
$l['deleted']='Deleted';
$l['file']='File';
$l['folder']='Folder';
$l['files']='Files';
$l['emptyFile']='Empty file';
$l['downloadLink'] = 'Download link';
$l['deletedDownloadLink']='Delete this link';
$l['deleteDownloadLink']='You are going to delete this link, are you sure?';
$l['clickHereToDownload'] = 'Click on the link to download the file';
$l['copyPasteToDownload'] = 'Click the secured link below or copy it to your browser\'s address bar to download the file.';
$l['possibleUntil'] = 'possible until';
$l['fileNotFound']='Sorry, the file you tried to download is not found.';
$l['no_folder_id'] = 'Invalid folder id has been passed with the request to the server!';
$l['path']='Path';

$l['selectFolder']='Select folder...';
$l['notifyRecursiveTitle']='Set notification on subfolders?';
$l['removeNotifyRecursiveTitle']='Remove notification from subfolders?';
$l['notifyRecursiveQuestion']='Do you want to apply this to all the subfolders?';
$l['unlock']='Unlock';
$l['lockedBy']='Locked by';
$l['lock']='Lock';

$l['shortVersion']='Ver.';
$l['fileIsLocked']='File is locked';

$l["fileId"] = "ID";
$l["fileFolder_id"] = "Folder";
$l["fileName"] = "Name";
$l["fileLocked_user_id"] = "Locked by";
$l["fileCtime"] = "Created at";
$l["fileMtime"] = "Last modified";
$l["fileSize"] = "Size";
$l["fileUser_id"] = "User";
$l["fileComment"] = "Comment";
$l["fileExtension"] = "Extension";
$l["fileExpire_time"] = "Expire time";
$l["fileRandom_code"] = "Random Code";

$l['createDownloadLink']='Create downloadlink';

$l['notifyFolderAdd'] = 'Folder %s was add to %s by %s';
$l['notifyFolderRename'] = 'Folder %s was renamed to %s by %s';
$l['notifyFolderMove'] = 'Folder %s was moved to %s by %s';
$l['notifyFolderDelete'] = 'Folder %s was deleted by %s';

$l['notifyFileAdd'] = 'File %s was add to %s by %s';
$l['notifyFileRename'] = 'File %s was renamed to %s by %s';
$l['notifyFileMove'] = 'File %s was moved to %s by %s';
$l['notifyFileDelete'] = 'File %s was deleted by %s';
$l['notifyFileUpdate'] = 'File %s was updated by %s';
$l['notificationEmailSubject'] = 'Updates in folder';

$l['downloadLinkExpired'] = "Sorry, the download link for this file has expired";
$l['recentFiles']="Files modified in the past 7 days";
